@@ -4,14 +4,11 @@
 # suite.  It provides some supporting functions to make it easier to write
 # tests.
 #
-# Copyright 2015 Russ Allbery <rra@cpan.org>
-#
-# This program is free software; you may redistribute it and/or modify it
-# under the same terms as Perl itself.
+# SPDX-License-Identifier: GPL-1.0-or-later OR Artistic-1.0-Perl
 
 package Test::Podlators;
 
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 
@@ -31,7 +28,7 @@ our (@EXPORT_OK, @ISA, $VERSION);
 # consistency is good).
 BEGIN {
     @ISA       = qw(Exporter);
-    $VERSION   = '2.00';
+    $VERSION   = '2.01';
     @EXPORT_OK = qw(
       read_snippet read_test_data slurp test_snippet test_snippet_with_io
     );
@@ -43,16 +40,14 @@ my $OLD_STDERR;
 # The file name used to capture standard error output.
 my $SAVED_STDERR;
 
-# Internal function to clean up the standard error output file.  The "1 while"
-# construct is for VMS, in case there are multiple versions of the file.
+# Internal function to clean up the standard error output file.  Leave the
+# temporary directory in place, since otherwise we race with other test
+# scripts trying to create the temporary directory when running tests in
+# parallel.
 sub _stderr_cleanup {
     if ($SAVED_STDERR && -f $SAVED_STDERR) {
         unlink($SAVED_STDERR);
     }
-    my $tmpdir = File::Spec->catdir('t', 'tmp');
-    if (-d $tmpdir) {
-        rmdir($tmpdir);
-    }
     return;
 }
 
@@ -66,7 +61,7 @@ END {
 sub _stderr_save {
     my $tmpdir = File::Spec->catdir('t', 'tmp');
     if (!-d $tmpdir) {
-        mkdir('t/tmp', 0777) or BAIL_OUT("cannot create t/tmp: $!");
+        mkdir($tmpdir, 0777) or BAIL_OUT("cannot create $tmpdir: $!");
     }
     my $path = File::Spec->catfile($tmpdir, "out$$.err");
 
@@ -95,7 +90,8 @@ sub _stderr_restore {
 # Read one test snippet from the provided relative file name and return it.
 # For the format, see t/data/snippets/README.
 #
-# $path - Relative path to read test data from
+# $path     - Relative path to read test data from
+# $encoding - Encoding of snippet (UTF-8 if not specified)
 #
 # Returns: Reference to hash of test data with the following keys:
 #            name      - Name of the test for status reporting
@@ -105,15 +101,16 @@ sub _stderr_restore {
 #            errors    - Expected errors
 #            exception - Text of exception (with file and line stripped)
 sub read_snippet {
-    my ($path) = @_;
+    my ($path, $encoding) = @_;
     $path = File::Spec->catfile('t', 'data', 'snippets', $path);
+    $encoding ||= 'UTF-8';
     my %data;
 
     # Read the sections and store them in the %data hash.
     my ($line, $section);
     open(my $fh, '<', $path) or BAIL_OUT("cannot open $path: $!");
     while (defined($line = <$fh>)) {
-        $line = decode('UTF-8', $line);
+        $line = decode($encoding, $line);
         if ($line =~ m{ \A \s* \[ (\S+) \] \s* \z }xms) {
             $section = $1;
         } elsif ($section) {
@@ -248,11 +245,14 @@ sub slurp {
 # loading the snippet, creating the formatter, running it, and checking the
 # results, and reports those results with Test::More.
 #
-# $class   - Class name of the formatter, as a string
-# $snippet - Path to the snippet file defining the test
+# $class       - Class name of the formatter, as a string
+# $snippet     - Path to the snippet file defining the test
+# $options_ref - Hash of options with the following keys:
+#   encoding - Set to use a non-standard encoding
 sub test_snippet {
-    my ($class, $snippet) = @_;
-    my $data_ref = read_snippet($snippet);
+    my ($class, $snippet, $options_ref) = @_;
+    my $encoding = defined($options_ref) ? $options_ref->{encoding} : undef;
+    my $data_ref = read_snippet($snippet, $encoding);
 
     # Create the formatter object.
     my $parser = $class->new(%{ $data_ref->{options} }, name => 'TEST');
@@ -273,14 +273,17 @@ sub test_snippet {
         $got =~ s{ \A .* \n [.]nh \n }{}xms;
     }
 
+    # Strip any trailing blank lines (Pod::Text likes to add them).
+    $got =~ s{ \n\s+ \z }{\n}xms;
+
     # Check the output, errors, and any exception.
     is($got, $data_ref->{output}, "$data_ref->{name}: output");
-    if ($data_ref->{errors}) {
-        is($stderr, $data_ref->{errors}, "$data_ref->{name}: errors");
+    if ($data_ref->{errors} || $stderr) {
+        is($stderr, $data_ref->{errors} || q{}, "$data_ref->{name}: errors");
     }
     if ($data_ref->{exception} || $exception) {
         if ($exception) {
-            $exception =~ s{ [ ] at [ ] .* }{}xms;
+            $exception =~ s{ [ ] at [ ] .* }{\n}xms;
         }
         is($exception, $data_ref->{exception}, "$data_ref->{name}: exception");
     }
@@ -309,7 +312,7 @@ sub test_snippet_with_io {
     # directive.
     my $tmpdir = File::Spec->catdir('t', 'tmp');
     if (!-d $tmpdir) {
-        mkdir($tmpdir, 0777);
+        mkdir($tmpdir, 0777) or BAIL_OUT("cannot create $tmpdir: $!");
     }
     my $input_file = File::Spec->catfile('t', 'tmp', "tmp$$.pod");
     open(my $input, '>', $input_file)
@@ -393,14 +396,14 @@ should be explicitly imported.
 
 =over 4
 
-=item read_snippet(PATH[, OPTIONS])
+=item read_snippet(PATH[, ENCODING])
 
 Read one test snippet from the provided relative file name and return it.  The
 path should be relative to F<t/data/snippets>.  For the format, see
 F<t/data/snippets/README>.
 
-OPTIONS, if present, is a hash that currently supports only one key: C<utf8>,
-to set a PerlIO input encoding layer of UTF-8 when reading the snippet.
+ENCODING, if present, specifies the encoding of the snippet.  If not given,
+the snippet is assumed to be encoded in C<UTF-8>.
 
 The result will be a hash with the following keys:
 
@@ -478,20 +481,24 @@ The output data for the test.  This is always present.
 Read the contents of FILE and return it as a string.  If STRIP is set to
 C<man>, strip off any Pod::Man header from the file before returning it.
 
-=item test_snippet(CLASS, SNIPPET)
+=item test_snippet(CLASS, SNIPPET[, OPTIONS])
 
 Test a formatter on a particular POD snippet.  This does all the work of
 loading the snippet, creating the formatter by instantiating CLASS, running
 it, and checking the results.  Results are reported with Test::More.
 
+OPTIONS, if present, is a reference to a hash of options.  Currently, only
+one key is supported: C<encoding>, which, if set, specifies the encoding of
+the snippet.
+
 =item test_snippet_with_io(CLASS, SNIPPET[, OPTIONS])
 
 The same as test_snippet(), except, rather than parsing the input into a
 string buffer, this function uses real, temporary input and output files.
 This can be used to test I/O layer handling and proper encoding.
 
-OPTIONS, if present, is a reference to a hash of options.  Currently, only
-one key is supported: C<perlio>, which, if set to true, will set a PerlIO
+OPTIONS, if present, is a reference to a hash of options.  Currently, only one
+key is supported: C<perlio_utf8>, which, if set to true, will set a PerlIO
 UTF-8 encoding layer on the output file before writing to it.
 
 =back
@@ -502,9 +509,13 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 Russ Allbery <rra@cpan.org>
+Copyright 2015-2016, 2018-2019 Russ Allbery <rra@cpan.org>
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
+
+# Local Variables:
+# copyright-at-end-flag: t
+# End:
